---
title: <span class="badge object-type-scalar"></span> SouthKoreanWon
---
# <span class="badge object-type-scalar"></span> SouthKoreanWon

Currency: South Korean Won (₩)

## Definition

```python
# Currency: South Korean Won (₩)
SouthKoreanWon: typing.Literal["currencyKRW"] = "currencyKRW"
```
